<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LXQtVolume</name>
    <message>
        <location filename="../lxqtvolume.cpp" line="64"/>
        <source>Increase sound volume</source>
        <translation>소리 음량 높이기</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="70"/>
        <source>Decrease sound volume</source>
        <translation>소리 음량 줄이기</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="76"/>
        <source>Mute/unmute sound volume</source>
        <translation>소리 음량 음소거/해제</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="137"/>
        <source>Volume Control: The following shortcuts can not be registered: %1</source>
        <translation>음량 제어: 다음 단축키는 등록할 수 없습니다: %1</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>Volume: %1%%2</source>
        <translation>음량: %1%%2</translation>
    </message>
    <message>
        <location filename="../lxqtvolume.cpp" line="290"/>
        <source>(muted)</source>
        <translation>(음소거됨)</translation>
    </message>
</context>
<context>
    <name>LXQtVolumeConfiguration</name>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="14"/>
        <source>Volume Control Settings</source>
        <translation>음량 제어 설정</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="20"/>
        <source>Device to control</source>
        <translation>제어할 장치</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="28"/>
        <source>ALSA</source>
        <translation>ALSA</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="35"/>
        <source>PulseAudio</source>
        <translation>PulseAudio</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="42"/>
        <source>OSS</source>
        <translation>OSS</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="57"/>
        <source>Behavior</source>
        <translation>동작</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="63"/>
        <source>Mute on middle click</source>
        <translation>가운데 클릭 시 음소거</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="70"/>
        <source>Allow volume beyond 100% (0dB)</source>
        <translation>100%를 초과하는 음량 허용 (0dB)</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="77"/>
        <source>Always notify about volume changes</source>
        <translation>음량 변경에 대해 항상 알림</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="84"/>
        <source>Notify about volume changes with keyboard</source>
        <translation>키보드로 음량 변경 알림</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="99"/>
        <source>Volume adjust step</source>
        <translation>음량 조정 단계</translation>
    </message>
    <message>
        <location filename="../lxqtvolumeconfiguration.ui" line="118"/>
        <source>External Mixer</source>
        <translation>외부 믹서</translation>
    </message>
</context>
<context>
    <name>VolumePopup</name>
    <message>
        <location filename="../volumepopup.cpp" line="59"/>
        <source>Launch mixer</source>
        <translation>믹서 실행</translation>
    </message>
    <message>
        <location filename="../volumepopup.cpp" line="60"/>
        <source>Mi&amp;xer</source>
        <translation>믹서(&amp;X)</translation>
    </message>
</context>
</TS>
